directory_walker

Function directory_walker 

pub(crate) fn directory_walker(
    path: &Path,
    ignored: &Vec<PathBuf>,
) -> Filter<Filter<FilterMap<IntoIter, impl FnMut(Result<DirEntry, Error>) -> Option<DirEntry>>, impl FnMut(&DirEntry) -> bool>, impl FnMut(&DirEntry) -> bool>
A helper function to set up a directory walker within a given directory.

This ignores symlinks. This also guarantees that the entries will be walked over in an order, sorted by file name. The signature on this function is complicated because of the functional implementation.